@@ -5,7 +5,7 @@
 ;;   Copyright (C) 2002,2003,2004,2005 Kiyoka Nishiyama
 ;;   This program was derived from yc.el-4.0.13(auther: knak)
 ;;
-;;     $Date: 2006/08/28 15:23:36 $
+;;     $Date: 2006/12/06 13:35:30 $
 ;;
 ;; This file is part of Sumibi
 ;;
@@ -135,6 +135,11 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
   :type  'boolean
   :group 'sumibi)
 
+(defcustom sumibi-history-max  100
+  "$B%f!<%6!<8GM-$NJQ49MzNr$N:GBgJ]B87o?t$r;XDj$9$k(B($B:G?7$+$i;XDj7o?t$N$_$,J]B8$5$l$k(B)"
+  :type  'integer
+  :group 'sumibi)
+
 
 (defface sumibi-guide-face
   '((((class color) (background light)) (:background "#E0E0E0" :foreground "#F03030")))
@@ -544,6 +549,13 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
 ;; $B=i4|2=(B
 ;;
 (defun sumibi-init ()
+  ;; $B:G=i$N(B n $B7o$N%j%9%H$r<hF@$9$k(B
+  (defun sumibi-take (arg-list n)
+    (let ((lst '()))
+      (dotimes (i n (reverse lst))
+	(let ((item (nth i arg-list)))
+	  (when item
+	    (push item lst))))))
 
   ;; $B%R%9%H%j%U%!%$%k$H%a%b%jCf$N%R%9%H%j%G!<%?$r%^!<%8$9$k(B
   (defun sumibi-merge-kakutei-history (base-list new-list)
@@ -595,10 +607,15 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
 		    (with-temp-file
 			sumibi-history-filename
 		      (insert (format "(setq sumibi-kakutei-history-saved '%s)" 
-				      (pp-to-string 
-				       (sumibi-merge-kakutei-history
-					sumibi-kakutei-history-saved
-					sumibi-kakutei-history)))))))
+				      (let ((lst
+					     (sumibi-take 
+					      (sumibi-merge-kakutei-history
+					       sumibi-kakutei-history-saved
+					       sumibi-kakutei-history)
+					      sumibi-history-max)))
+					(if (functionp 'pp-to-string)
+					    (pp-to-string lst)
+					  (prin1-to-string lst))))))))
 		;; SSL$B>ZL@=q$N%U%!%$%k$r:o=|$9$k(B
 		(delete-file sumibi-server-cert-file)))
 
@@ -620,7 +637,7 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
 		(error "Error : cert file create miss!")
 	      (format "--cacert '%s' " sumibi-server-cert-file))
 	    " --insecure ")
-	  (format " --header 'Content-Type: text/xml' " sumibi-server-timeout)
+	  (format " --header 'Content-Type: text/xml' ")
 	  (format " --header 'SOAPAction:urn:SumibiConvert#%s' " func-name)
 	  sumibi-server-url " "
 	  (format (concat "--data '"
@@ -685,6 +702,7 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
   (sumibi-debug-print (format "henkan-input :[%s]\n"  yomi))
 
   (message "Requesting to sumibi server...")
+  
   (let* (
 	 (result (sumibi-soap-request "doSumibiConvertSexp" (list yomi
 								  ""
@@ -1139,6 +1157,14 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
   (interactive)
 ;  (print last-command)			; DEBUG
 
+  ;; $BHs(BSSL$B$N7Y9p$r=P$9(B
+  (when (and (string-match "^[ ]*http:" sumibi-server-url)
+	     (> 1 sumibi-timer-rest))
+    (progn
+      ;; $B7Y9p$r=P$7$F%]!<%:$9$k(B
+      (message "sumibi.el: !! $BHs(BSSL$B$GDL?.$9$k@_Dj$K$J$C$F$$$^$9!#(B !!")
+      (sleep-for 2)))
+
   (cond 
    ;; $B%?%$%^!<%$%Y%s%H$r@_Dj$7$J$$>r7o(B
    ((or
@@ -1384,7 +1410,8 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
   "$B%j%"%k%?%$%`$GJQ49Cf$N%,%$%I$r=P$9(B
 sumibi-mode$B$,(BON$B$N4VCf8F$S=P$5$l$k2DG=@-$,$"$k!&(B"
   (cond
-   ((> 1 sumibi-timer-rest)
+   ((or (null sumibi-mode)
+	(> 1 sumibi-timer-rest))
     (cancel-timer sumibi-timer)
     (setq sumibi-timer nil)
     (delete-overlay sumibi-guide-overlay))
@@ -1559,10 +1586,11 @@ point $B$+$i9TF,J}8~$KF1<o$NJ8;zNs$,B3$/4V$r4A;zJQ49$7$^$9!#(B
 (setq default-input-method "japanese-sumibi")
 
 (defconst sumibi-version
-"0.7.1"
+"0.7.3"
   )
 (defun sumibi-version (&optional arg)
   "$BF~NO%b!<%IJQ99(B"
   (interactive "P")
   (message sumibi-version))
+
 (provide 'sumibi)
